==> todotask2.0.1.zip: todotask2/app/controllers/db.class.php <==
<?php

require_once(TODOTASK_DIR.'/app/controllers/ctrl.class.php');

class Db extends Ctrl {

	private $conn = false;
	private $disconncnt = 0;	// 接続できなかった回数

	function __construct(&$conn=false){
		if( !$this->conn ) $this->conn = $conn;
		$this->connect();
	}

	function __destruct(){
		$this->disconnect();
	}

	function connect(){
		if( $this->conn ){
			return true;
		}
		$this->conn = mysql_connect(DB_HOST, DB_USER, DB_PASS);
		if (!$this->conn) {
			// ヘッダー送出済み
			gfMsgWindow("" ,MSG_MODE_NOTE ,ERR_TITLE , DB_ERR_CONNECT ,ROOT_URL,MSG_NOR);
			return false;
		}

		mysql_select_db(DB_NAME,$this->conn);
		$this->exec_sql("set names ".DB_ENCTYPE.";");
		return true;
	}

	function disconnect(){
		if( $this->conn ){
			mysql_close($this->conn);
		}
		return true;
	}

	public function begin_trans(){
		// トランザクションモードを利用しない場合
		if (!DB_TRANS) {
			return true;
		}

		$sql = "begin;";
		return $this->exec_sql($sql);
	}

	public function commit_trans($bln_cmt){
		// トランザクションモードを利用しない場合
		if (!DB_TRANS) {
			return true;
		}

		if( $bln_cmt ){
			$sql = "commit;";
		} else {
			$sql = "rollback;";
		}
		$rtn = $this->exec_sql($sql);
		return $rtn;
	}

	public function get_rs($sSQL){
		$this->connect();
		$res = mysql_query($sSQL, $this->conn);
		if (!$res) { 
			gfDebug(DB_ERR_001."get_rs ".$sSQL."::". mysql_error());
		}
		return $res;
	}

	public function exec_sql($sSQL){
		$this->connect();
		$res = mysql_query($sSQL, $this->conn);
		if (!$res) { 
			gfDebug(DB_ERR_001."exec_sql ".$sSQL."::". mysql_error());
		}
		return $res;
	}

	public function free_rs(&$rs){
		mysql_free_result($rs);
		return true;
	}

	public function affected_rows(){
		return mysql_affected_rows();
	}

	public function get_lastid(){
		//クエリ結果初期化
		$Ret = "";

		//追加した放送局No検索
		$sSQL = "";
		$sSQL = $sSQL."select ";
		$sSQL = $sSQL."	last_insert_id() last_id;";

		$rs = $this->get_rs($sSQL);
		if($rs) {
			while( $row = $this->get_row($rs)){
				$Ret = gfGetDBFields($row,"last_id"); 
			}
			$this->free_rs($rs);
		}
		return $Ret;
	}


	public function get_row($rs){
		$row = false; 
		if($rs) {
			$row = mysql_fetch_array($rs);
		}
		return $row;
	}

	// レコードセットから情報を取得する為の関数
	public function get_col($row,$sFields){
		$sRet = "";
		if(is_array($row)) {
			// 取り出した文字列を表示
			$sRet = mb_convert_encoding( $row[$sFields], PAGE_ENCTYPE, DB_ENCTYPE);
		}
		return $sRet;
	}
	
	// ログ書き込み処理
	public function InsLog($group_no, $task_no, $taskbox_id ,$note ,$status ,$memo) {
	
		// ログを記録しないモードである場合
		if (LOG_ACT != 1) {
			return true;
		}
	
	
		// ログを追加する。
		$sSQL = "";
		$sSQL = $sSQL."insert into log_tbl (";
		$sSQL = $sSQL."	group_no,";
		$sSQL = $sSQL."	task_no,";
		$sSQL = $sSQL."	taskbox_id,";
		$sSQL = $sSQL."	user_id,";
		$sSQL = $sSQL."	note,";
		$sSQL = $sSQL."	status,";	// タスク状態 (0:未処理/1:処理中/2:終了/3:延期/4:破棄/10:グループ廃棄/12:グループ新設)
		$sSQL = $sSQL."	memo,";
		$sSQL = $sSQL."	remotehost,";
		$sSQL = $sSQL."	upddate,";
		$sSQL = $sSQL."	insdate";
		$sSQL = $sSQL.") values (";
		$sSQL = $sSQL.gfQt($group_no).",";
		$sSQL = $sSQL.gfQtNum($task_no,"0").",";
		$sSQL = $sSQL.gfQtNum($taskbox_id,"0").",";
		$sSQL = $sSQL.gfQt($_SESSION[SESSION_LOGIN]).",";
		$sSQL = $sSQL.gfQt($note).",";
		$sSQL = $sSQL.gfQt($status).",";
		$sSQL = $sSQL.gfQt($memo).",";
		$sSQL = $sSQL.gfQt($_SERVER['REMOTE_ADDR']).",";
		$sSQL = $sSQL."now(),";
		$sSQL = $sSQL."now()";
		$sSQL = $sSQL.") ";

		$this->exec_sql($sSQL);
	}
	
}

?>

==> todotask2.1.2.zip: todotask2/app/controllers/db.class.php <==
<?php

require_once(TODOTASK_DIR.'/app/controllers/ctrl.class.php');

class Db extends Ctrl {

	private $conn = false;
	private $disconncnt = 0;	// 接続できなかった回数

	function __construct(&$conn=false){
		if( !$this->conn ) $this->conn = $conn;
		$this->connect();
	}

	function __destruct(){
		$this->disconnect();
	}

	function connect(){
		if( $this->conn ){
			return true;
		}
		$this->conn = mysql_connect(DB_HOST, DB_USER, DB_PASS);
		if (!$this->conn) {
			// ヘッダー送出済み
			gfMsgWindow("" ,MSG_MODE_NOTE ,ERR_TITLE , DB_ERR_CONNECT ,ROOT_URL,MSG_NOR);
			return false;
		}

		mysql_select_db(DB_NAME,$this->conn);
		$this->exec_sql("set names ".DB_SETNAMES.";");
		return true;
	}

	function disconnect(){
		if( $this->conn ){
			mysql_close($this->conn);
		}
		return true;
	}

	public function begin_trans(){
		// トランザクションモードを利用しない場合
		if (!DB_TRANS) {
			return true;
		}

		$sql = "begin;";
		return $this->exec_sql($sql);
	}

	public function commit_trans($bln_cmt){
		// トランザクションモードを利用しない場合
		if (!DB_TRANS) {
			return true;
		}

		if( $bln_cmt ){
			$sql = "commit;";
		} else {
			$sql = "rollback;";
		}
		$rtn = $this->exec_sql($sql);
		return $rtn;
	}

	public function get_rs($sSQL){
		$this->connect();
		$res = mysql_query($sSQL, $this->conn);
		if (!$res) { 
			gfDebug(DB_ERR_001."get_rs ".$sSQL."::". mysql_error());
		}
		return $res;
	}

	public function exec_sql($sSQL){
		$this->connect();
		$res = mysql_query($sSQL, $this->conn);
		if (!$res) { 
			gfDebug(DB_ERR_001."exec_sql ".$sSQL."::". mysql_error());
		}
		return $res;
	}

	public function free_rs(&$rs){
		mysql_free_result($rs);
		return true;
	}

	public function affected_rows(){
		return mysql_affected_rows();
	}

	public function get_lastid(){
		//クエリ結果初期化
		$Ret = "";

		//追加した放送局No検索
		$sSQL = "";
		$sSQL = $sSQL."select ";
		$sSQL = $sSQL."	last_insert_id() last_id;";

		$rs = $this->get_rs($sSQL);
		if($rs) {
			while( $row = $this->get_row($rs)){
				$Ret = gfGetDBFields($row,"last_id"); 
			}
			$this->free_rs($rs);
		}
		return $Ret;
	}


	public function get_row($rs){
		$row = false; 
		if($rs) {
			$row = mysql_fetch_array($rs);
		}
		return $row;
	}

	// レコードセットから情報を取得する為の関数
	public function get_col($row,$sFields){
		$sRet = "";
		if(is_array($row)) {
			// 取り出した文字列を表示
			$sRet = mb_convert_encoding( $row[$sFields], PAGE_ENCTYPE, DB_ENCTYPE);
		}
		return $sRet;
	}
	
	// ログ書き込み処理
	public function InsLog($group_no, $task_no, $taskbox_id ,$note ,$status ,$memo) {
	
		// ログを記録しないモードである場合
		if (LOG_ACT != 1) {
			return true;
		}
	
	
		// ログを追加する。
		$sSQL = "";
		$sSQL = $sSQL."insert into log_tbl (";
		$sSQL = $sSQL."	group_no,";
		$sSQL = $sSQL."	task_no,";
		$sSQL = $sSQL."	taskbox_id,";
		$sSQL = $sSQL."	user_id,";
		$sSQL = $sSQL."	note,";
		$sSQL = $sSQL."	status,";	// タスク状態 (0:未処理/1:処理中/2:終了/3:延期/4:破棄/10:グループ廃棄/12:グループ新設)
		$sSQL = $sSQL."	memo,";
		$sSQL = $sSQL."	remotehost,";
		$sSQL = $sSQL."	upddate,";
		$sSQL = $sSQL."	insdate";
		$sSQL = $sSQL.") values (";
		$sSQL = $sSQL.gfQt($group_no).",";
		$sSQL = $sSQL.gfQtNum($task_no,"0").",";
		$sSQL = $sSQL.gfQtNum($taskbox_id,"0").",";
		$sSQL = $sSQL.gfQt($_SESSION[SESSION_LOGIN]).",";
		$sSQL = $sSQL.gfQt($note).",";
		$sSQL = $sSQL.gfQt($status).",";
		$sSQL = $sSQL.gfQt($memo).",";
		$sSQL = $sSQL.gfQt($_SERVER['REMOTE_ADDR']).",";
		$sSQL = $sSQL."now(),";
		$sSQL = $sSQL."now()";
		$sSQL = $sSQL.") ";

		$this->exec_sql($sSQL);
	}
	
}

?>
